import niki.Welt;
import niki.Niki;

public class Roboter2 extends Niki{

	public Roboter2 (Welt welt){
		super(welt);
	}

	public void rechts(){
		links();
		links();
		links();
	}

	public void vorZurWand(){
		while (vorneFrei()){
			vor();
		}
	}

	public void rechtsKurve(){
		rechts();
		vor();
		rechts();
	}

	public void linksKurve(){
		links();
		vor();
		links();
	}

	public boolean rechtsFrei(){
		rechts();
		boolean frei=vorneFrei();
		links();
		return frei;
	}

	public boolean linksFrei(){
		links();
		boolean frei=vorneFrei();
		rechts();
		return frei;
	}

	public void streckeAufraeumen(){
		while (vorneFrei()){
			while (!feldLeer()){
				nimm();
			}
			vor();
		}
		while (!feldLeer()){
			nimm();
		}
	}

}
