import niki.Welt;
import niki.Niki;

public class Rundlauf3{
    public static void main(String[] args){
        Welt meineWelt = new Welt("kleineWelt.welt");
        Roboter2 meinRoboter = new Roboter2(meineWelt);

	meinRoboter.vorZurWand();
	while (meinRoboter.rechtsFrei()){
		meinRoboter.rechtsKurve();
		meinRoboter.vorZurWand();
		if (meinRoboter.linksFrei()){
			meinRoboter.linksKurve();
			meinRoboter.vorZurWand();
		}else{
			meinRoboter.links();
		}
	}
    }
}
